@@ -111,6 +111,10 @@ async def start_app(app: FastAPI):
 
         setup_gitlab(app)
     except ValueError:
+        logger.info(
+            "Gitlab dependencies are missing, if you are planning to use workflows make sure the optional "
+            + "dependencies are installed"
+        )
         pass  # App probably doesn't want to use gitlab
 
     await create_indexes()
